@@ -2,18 +2,18 @@
 #
 # Copyright (C) 2020 CERN.
 #
-# Docker-Services-CLI is free software; you can redistribute it and/or modify it
-# under the terms of the MIT License; see LICENSE file for more details.
+# Docker-Services-CLI is free software; you can redistribute it and/or modify
+# it under the terms of the MIT License; see LICENSE file for more details.
 
 """Services module."""
 
-from os import path
-from subprocess import check_call, Popen, PIPE
 import time
+from os import path
+from subprocess import PIPE, Popen, check_call
 
 import click
 
-from .config import DOCKER_SERVICES_FILEPATH, MYSQL, POSTGRESQL
+from .config import DOCKER_SERVICES_FILEPATH, MYSQL, POSTGRESQL, SERVICE_TYPES
 
 
 def _run_healthcheck_command(command, verbose=False):
@@ -68,7 +68,8 @@ def mysql_healthcheck(*args, **kwargs):
     """Mysql healthcheck."""
     filepath = kwargs['filepath']
     verbose = kwargs['verbose']
-    password = MYSQL["MYSQL_ROOT_PASSWORD"]
+    password = \
+        MYSQL["CONTAINER_CONFIG_ENVIRONMENT_VARIABLES"]["MYSQL_ROOT_PASSWORD"]
 
     return _run_healthcheck_command([
         "docker-compose",
@@ -83,6 +84,24 @@ def mysql_healthcheck(*args, **kwargs):
     ], verbose)
 
 
+def rabbitmq_healthcheck(*args, **kwargs):
+    """Rabbitmq healthcheck."""
+    filepath = kwargs['filepath']
+    verbose = kwargs['verbose']
+
+    return _run_healthcheck_command([
+        "docker-compose",
+        "--file",
+        filepath,
+        "exec",
+        "-T",
+        "rabbitmq",
+        "bash",
+        "-c",
+        "rabbitmq-diagnostics check_running"
+    ], verbose)
+
+
 def redis_healthcheck(*args, **kwargs):
     """Redis healthcheck."""
     filepath = kwargs['filepath']
@@ -105,9 +124,10 @@ def redis_healthcheck(*args, **kwargs):
 
 
 HEALTHCHECKS = {
-    "es": es_healthcheck,
+    "elasticsearch": es_healthcheck,
     "postgresql": postgresql_healthcheck,
     "mysql": mysql_healthcheck,
+    "rabbitmq": rabbitmq_healthcheck,
     "redis": redis_healthcheck,
 }
 """Health check functions module path, as string."""
@@ -133,7 +153,7 @@ def wait_for_services(services, filepath=DOCKER_SERVICES_FILEPATH,
         ready = check(filepath=filepath, verbose=verbose)
         while not ready and try_ < max_retries:
             click.secho(
-                f"{service} not ready at {try_} retries, waiting " \
+                f"{service} not ready at {try_} retries, waiting "
                 f"{exp_backoff_time}s",
                 fg="yellow"
             )
@@ -157,8 +177,12 @@ def services_up(services, filepath=DOCKER_SERVICES_FILEPATH, wait=True,
     there is no need to, so --build is not a slow default. In addition
     ``--detach`` is not supported in 1.17.0 or previous.
     """
+    services = services or [service
+                            for _, services in SERVICE_TYPES.items()
+                            for service in services]
     if not path.exists(filepath):
-        click.secho(f"Filepaht {filepath} for docker-services.yml file does not exist.", fg="red")
+        click.secho(f"Filepaht {filepath} for docker-services.yml file does"
+                    "not exist.", fg="red")
         exit(1)
 
     command = ["docker-compose", "--file", filepath, "up", "-d"]
@@ -176,6 +200,6 @@ def services_down(filepath=DOCKER_SERVICES_FILEPATH):
     It does not requries the services. It stops containers and removes
     containers, networks, volumes, and images created by ``up``.
     """
-    command = ["docker-compose", "--file", filepath, "down"]
+    command = ["docker-compose", "--file", filepath, "down", "--volumes"]
 
     check_call(command)
